@@ -17,7 +17,7 @@
  */
 
 /* Maximum number of fields that can be displayed */
-#define MAX_FIELDS		64
+#define MAX_FIELDS		128
 
 /* Maximum number of header lines */
 #define HDR_LINES 		10
@@ -45,7 +45,7 @@ static struct option opts[] = {
 	{ "file", 1, NULL, 'f' },
 	{ "help", 0, NULL, 'h' },
 	{ "interval", 1, NULL, 'i' },
-	{ "key", 1, NULL, 'k' },
+	{ "keys", 1, NULL, 'k' },
 	{ "subject", 1, NULL, 's' },
 	{ "width", 1, NULL, 'w' },
 };
@@ -61,7 +61,7 @@ static int usage(char *name, int exit_code)
 	fprintf(stderr, "\t-V --version\t\tPrint Version of Program\n");
 	fprintf(stderr, "\t-c --count <count>\t"
 			"Print <count> number of intervals\n");
-	fprintf(stderr, "\t-d --dumpt\t\t"
+	fprintf(stderr, "\t-d --dump\t\t"
 			"Dump list of available files/keys\n");
 	fprintf(stderr, "\t-f --file <file>\tStatistics file to use\n");
 	fprintf(stderr, "\t-h --help\t\tThis help message\n");
@@ -119,11 +119,19 @@ static int map_field_params(struct lnstat_file *lnstat_files,
 				fps->params[j].lf->file->interval.tv_sec =
 								interval;
 				if (!fps->params[j].print.width)
-					fps->params[j].print.width = 
+					fps->params[j].print.width =
 							FIELD_WIDTH_DEFAULT;
-				j++;
+				
+				if (++j >= MAX_FIELDS - 1) {
+					fprintf(stderr,
+						"WARN: MAX_FIELDS (%d) reached,"
+						" truncating number of keys\n",
+						MAX_FIELDS);
+					goto full;
+				}
 			}
 		}
+	full:
 		fps->num = j;
 		return 1;
 	}
@@ -158,7 +166,7 @@ static struct table_hdr *build_hdr_string(struct lnstat_file *lnstat_files,
 
 	for (i = 0; i < HDR_LINES; i++) {
 		th.hdr[i] = malloc(HDR_LINE_LENGTH);
-		memset(th.hdr[i], 0, sizeof(th.hdr[i]));
+		memset(th.hdr[i], 0, HDR_LINE_LENGTH);
 	}
 
 	for (i = 0; i < fps->num; i++) {
@@ -204,7 +212,7 @@ static int print_hdr(FILE *of, struct table_hdr *th)
 	}
 	return 0;
 }
-		
+
 
 int main(int argc, char **argv)
 {
@@ -218,14 +226,14 @@ int main(int argc, char **argv)
 		MODE_NORMAL,
 	} mode = MODE_NORMAL;
 
-	unsigned long count = 0;
+	unsigned long count = 1;
 	static struct field_params fp;
 	int num_req_files = 0;
 	char *req_files[LNSTAT_MAX_FILES];
-	
+
 	/* backwards compatibility mode for old tools */
 	basename = strrchr(argv[0], '/');
-	if (basename) 
+	if (basename)
 		basename += 1;	  /* name after slash */
 	else
 		basename = argv[0]; /* no slash */
@@ -240,7 +248,7 @@ int main(int argc, char **argv)
 		num_req_files = 1;
 	}
 
-	while ((c = getopt_long(argc, argv,"Vc:df:h?i:k:s:w:", 
+	while ((c = getopt_long(argc, argv,"Vc:df:h?i:k:s:w:",
 				opts, NULL)) != -1) {
 		int i, len = 0;
 		char *tmp, *tok;
@@ -256,7 +264,7 @@ int main(int argc, char **argv)
 				req_files[num_req_files++] = strdup(optarg);
 				break;
 			case '?':
-			case 'h':       
+			case 'h':
 				usage(argv[0], 0);
 				break;
 			case 'i':
@@ -269,8 +277,13 @@ int main(int argc, char **argv)
 				for (tok = strtok(tmp, ",");
 				     tok;
 				     tok = strtok(NULL, ",")) {
-					if (fp.num >= MAX_FIELDS)
+					if (fp.num >= MAX_FIELDS) {
+						fprintf(stderr, 
+							"WARN: too many keys"
+							" requested: (%d max)\n",
+							MAX_FIELDS);
 						break;
+					}
 					fp.params[fp.num++].name = tok;
 				}
 				break;
@@ -315,12 +328,12 @@ int main(int argc, char **argv)
 
 		if (!map_field_params(lnstat_files, &fp, interval))
 			exit(1);
-	
+
 		header = build_hdr_string(lnstat_files, &fp, 80);
 		if (!header)
 			exit(1);
 
-		if (interval < 1 ) 
+		if (interval < 1 )
 			interval=1;
 
 		for (i = 0; i < count; i++) {
@@ -328,6 +341,7 @@ int main(int argc, char **argv)
 				print_hdr(stdout, header);
 			lnstat_update(lnstat_files);
 			print_line(stdout, lnstat_files, &fp);
+			fflush(stdout);
 			sleep(interval);
 		}
 	}
